@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -12,8 +12,7 @@
 #include <MessageComposer/PluginEditorConvertTextInterface>
 
 class RichTextComposerNgTest;
-
-namespace PimCommonAutoCorrection
+namespace TextAutoCorrection
 {
 class AutoCorrection;
 }
@@ -33,9 +32,9 @@ class MESSAGECOMPOSER_EXPORT RichTextComposerNg : public KPIMTextEdit::RichTextC
 public:
     explicit RichTextComposerNg(QWidget *parent = nullptr);
     ~RichTextComposerNg() override;
+    Q_REQUIRED_RESULT TextAutoCorrection::AutoCorrection *autocorrection() const;
+    void setAutocorrection(TextAutoCorrection::AutoCorrection *autocorrect);
 
-    Q_REQUIRED_RESULT PimCommonAutoCorrection::AutoCorrection *autocorrection() const;
-    void setAutocorrection(PimCommonAutoCorrection::AutoCorrection *autocorrect);
     void setAutocorrectionLanguage(const QString &lang);
 
     void fillComposerTextPart(MessageComposer::TextPart *textPart);
