@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -15,9 +15,7 @@ MessageFactoryReplyJob::MessageFactoryReplyJob(QObject *parent)
 {
 }
 
-MessageFactoryReplyJob::~MessageFactoryReplyJob()
-{
-}
+MessageFactoryReplyJob::~MessageFactoryReplyJob() = default;
 
 void MessageFactoryReplyJob::start()
 {
