@@ -1,15 +1,15 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef AttachmentClipBoardJob_H
-#define AttachmentClipBoardJob_H
+#pragma once
 
 #include "MessageCore/AttachmentLoadJob"
 #include "messagecomposer_export.h"
-namespace MessageComposer {
+namespace MessageComposer
+{
 /**
  * @brief The AttachmentClipBoardJob class
  * @author Laurent Montel <montel@kde.org>
@@ -28,4 +28,3 @@ private:
     void addAttachment(const QByteArray &data, const QString &attachmentName);
 };
 }
-#endif // AttachmentClipBoardJob_H
