@@ -4,8 +4,7 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MESSAGECOMPOSER_SENDLATERCREATEJOB_H
-#define MESSAGECOMPOSER_SENDLATERCREATEJOB_H
+#pragma once
 
 #include "sendlaterinfo.h"
 #include "sendlaterjob.h"
@@ -25,8 +24,6 @@ protected:
     Q_REQUIRED_RESULT QString getErrorString(SendLaterJob::Error code, const QString &detail) const override;
 
 private:
-    SendLaterInfo mInfo;
+    const SendLaterInfo mInfo;
 };
 }
-
-#endif
