@@ -260,7 +260,7 @@ void Pane::setXmlGuiClient(KXMLGUIClient *xmlGuiClient)
         d->mActivateNextTabAction->setEnabled(false);
         d->mActivateNextTabAction->setIcon(QIcon::fromTheme(nextIcon));
         d->mXmlGuiClient->actionCollection()->setDefaultShortcuts(d->mActivateNextTabAction, nextShortcut);
-        connect(d->mActivateNextTabAction, &QAction::triggered, [this]() {
+        connect(d->mActivateNextTabAction, &QAction::triggered, this, [this]() {
             d->activateNextTab();
         });
         d->mActionMenu->addAction(d->mActivateNextTabAction);
@@ -644,6 +644,10 @@ void Pane::PanePrivate::closeTab(QWidget *w)
 
     auto wWidget = qobject_cast<Widget *>(w);
     if (wWidget) {
+        const bool isLocked = wWidget->isLocked();
+        if (isLocked) {
+            return;
+        }
         wWidget->saveCurrentSelection();
     }
 
@@ -677,6 +681,7 @@ void Pane::PanePrivate::onCurrentTabChanged()
     Q_EMIT q->currentTabChanged();
 
     auto w = static_cast<Widget *>(q->currentWidget());
+    mCloseTabButton->setEnabled(!w->isLocked());
 
     QItemSelectionModel *s = mWidgetSelectionHash[w];
 
@@ -702,12 +707,17 @@ void Pane::PanePrivate::onTabContextMenuRequest(const QPoint &pos)
 
     QMenu menu(q);
 
-    QAction *closeTabAction = menu.addAction(i18nc("@action:inmenu", "Close Tab"));
-    closeTabAction->setIcon(QIcon::fromTheme(QStringLiteral("tab-close")));
+    QAction *closeTabAction = nullptr;
+    if (!w->isLocked()) {
+        closeTabAction = menu.addAction(i18nc("@action:inmenu", "Close Tab"));
+        closeTabAction->setIcon(QIcon::fromTheme(QStringLiteral("tab-close")));
+    }
 
     QAction *allOtherAction = menu.addAction(i18nc("@action:inmenu", "Close All Other Tabs"));
     allOtherAction->setIcon(QIcon::fromTheme(QStringLiteral("tab-close-other")));
 
+    menu.addSeparator();
+
     QAction *lockTabAction = menu.addAction(w->isLocked() ? i18nc("@action:inmenu", "Unlock Tab") : i18nc("@action:inmenu", "Lock Tab"));
     lockTabAction->setIcon(w->isLocked() ? QIcon::fromTheme(QStringLiteral("lock")) : QIcon::fromTheme(QStringLiteral("unlock")));
 
@@ -723,7 +733,8 @@ void Pane::PanePrivate::onTabContextMenuRequest(const QPoint &pos)
             }
 
             auto other = qobject_cast<Widget *>(q->widget(i));
-            if (other) {
+            const bool isLocked = other->isLocked();
+            if (!isLocked && other) {
                 widgets << other;
             }
         }
@@ -734,13 +745,17 @@ void Pane::PanePrivate::onTabContextMenuRequest(const QPoint &pos)
         }
 
         updateTabControls();
-    } else if (action == closeTabAction) {
+    } else if (closeTabAction && (action == closeTabAction)) {
         closeTab(q->widget(indexBar));
     } else if (action == lockTabAction) {
         auto tab = qobject_cast<Widget *>(q->widget(indexBar));
         const bool isLocked = !tab->isLocked();
         tab->setLockTab(isLocked);
         q->setTabIcon(indexBar, isLocked ? QIcon::fromTheme(QStringLiteral("lock")) : QIcon::fromTheme(QStringLiteral("unlock")));
+        q->tabBar()->tabButton(indexBar, QTabBar::RightSide)->setEnabled(!isLocked);
+        if (q->tabBar()->currentIndex() == indexBar) {
+            mCloseTabButton->setEnabled(!isLocked);
+        }
     }
 }
 
@@ -1133,16 +1148,18 @@ void Pane::writeConfig(bool restoreSession)
 
     if (restoreSession) {
         conf.writeEntry(QStringLiteral("currentIndex"), currentIndex());
-        conf.writeEntry(QStringLiteral("tabNumber"), count());
 
+        int elementTab = 0;
         for (int i = 0; i < count(); ++i) {
             auto w = qobject_cast<Widget *>(widget(i));
-            if (w) {
-                KConfigGroup grp(MessageList::MessageListSettings::self()->config(), QStringLiteral("MessageListTab%1").arg(i));
+            if (w && w->currentCollection().isValid()) {
+                KConfigGroup grp(MessageList::MessageListSettings::self()->config(), QStringLiteral("MessageListTab%1").arg(elementTab));
                 grp.writeEntry(QStringLiteral("collectionId"), w->currentCollection().id());
                 grp.writeEntry(QStringLiteral("HeaderState"), w->view()->header()->saveState());
+                elementTab++;
             }
         }
+        conf.writeEntry(QStringLiteral("tabNumber"), elementTab);
     }
     conf.sync();
 }
