@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -18,9 +18,7 @@ ViewerGrantleeThemeSupportTest::ViewerGrantleeThemeSupportTest(QObject *parent)
 {
 }
 
-ViewerGrantleeThemeSupportTest::~ViewerGrantleeThemeSupportTest()
-{
-}
+ViewerGrantleeThemeSupportTest::~ViewerGrantleeThemeSupportTest() = default;
 
 void ViewerGrantleeThemeSupportTest::initTestCase()
 {
