@@ -1,19 +1,18 @@
 /*
-   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "dkimresultattribute.h"
 #include <QDataStream>
+#include <QIODevice>
 
 using namespace MessageViewer;
 class MessageViewer::DKIMResultAttributePrivate
 {
 public:
-    DKIMResultAttributePrivate()
-    {
-    }
+    DKIMResultAttributePrivate() = default;
 
     int error = -1;
     int warning = -1;
@@ -25,10 +24,7 @@ DKIMResultAttribute::DKIMResultAttribute()
 {
 }
 
-DKIMResultAttribute::~DKIMResultAttribute()
-{
-    delete d;
-}
+DKIMResultAttribute::~DKIMResultAttribute() = default;
 
 QByteArray DKIMResultAttribute::type() const
 {
