@@ -1,12 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2018-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "templatesinsertcommandactiontest.h"
-#include "templatesinsertcommandaction.h"
 #include "templatescommandmenu.h"
+#include "templatesinsertcommandaction.h"
 #include <QMenu>
 #include <QTest>
 QTEST_MAIN(TemplatesInsertCommandActionTest)
@@ -21,6 +21,6 @@ void TemplatesInsertCommandActionTest::shouldHaveDefaultValue()
     TemplateParser::TemplatesInsertCommandAction act;
     QVERIFY(act.menu());
     QVERIFY(!act.menu()->isEmpty());
-    auto *menu = act.findChild<TemplateParser::TemplatesCommandMenu *>(QStringLiteral("templatescommandmenu"));
+    auto menu = act.findChild<TemplateParser::TemplatesCommandMenu *>(QStringLiteral("templatescommandmenu"));
     QVERIFY(menu);
 }
