@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2011-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2011-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,7 +15,6 @@ namespace Util
 {
 Q_REQUIRED_RESULT QStringList keywords();
 Q_REQUIRED_RESULT QStringList keywordsWithArgs();
-TEMPLATEPARSER_TESTS_EXPORT Q_REQUIRED_RESULT QString removeSpaceAtBegin(const QString &selection);
+Q_REQUIRED_RESULT TEMPLATEPARSER_TESTS_EXPORT QString removeSpaceAtBegin(const QString &selection);
 }
 }
-
